@@ -94,7 +94,7 @@ class Rubber;
 
 class DominoStyle : public TDEStyle
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 	friend class DominoStyleConfig;
 
@@ -188,7 +188,7 @@ public:
 				const TQStyleOption &o,
 				const TQWidget *w = 0) const;
 
-	int styleHint(TQ_StyleHint,
+	int styleHint(StyleHint,
 				const TQStyleControlElementData &ceData,
 				ControlElementFlags elementFlags,
 				const TQStyleOption & = TQStyleOption::Default,
